@@ -1,5 +1,7 @@
 #                                          -*- ruby -*-
-# Time-stamp: "98/07/15 16:57:21 tateishi"
+# extconf.rb
+#
+# Modified at: <1999/8/19 06:38:55 by ttate> 
 #
 
 require 'mkmf'
@@ -7,12 +9,15 @@ require 'mkmf'
 $CFLAGS = ""
 $LDFLAGS = "-lshadow"
 
-ok = have_library("shadow","getpwnam")
+if( ! (ok = have_library("shadow","getspent")) )
+  $LDFLAGS = ""
+  ok = have_func("getspent")
+end
+
 ok &= have_func("sgetspent")
 ok &= have_func("fgetspent")
 ok &= have_func("setspent")
 ok &= have_func("endspent")
-ok &= have_func("getspent")
 ok &= have_func("lckpwdf")
 ok &= have_func("ulckpwdf")
 
